pub struct Mailbox {
pub name: Option<String>,
pub email: Address,
}Expand description
Represents an email address with an optional name for the sender/recipient.
This type contains email address and the sender/recipient name (Some Name <user@domain.tld> or withoutname@domain.tld).
NOTE: Enable feature “serde” to be able to serialize/deserialize it using serde.
Examples
You can create a Mailbox from a string and an Address:
let address = Address::new("example", "email.com")?;
let mailbox = Mailbox::new(None, address);You can also create one from a string literal:
let mailbox: Mailbox = "John Smith <example@email.com>".parse()?;Fields
name: Option<String>The name associated with the address.
email: AddressThe email address itself.
Implementations
Sourceimpl Mailbox
impl Mailbox
Sourcepub fn new(name: Option<String>, email: Address) -> Mailbox
pub fn new(name: Option<String>, email: Address) -> Mailbox
Creates a new Mailbox using an email address and the name of the recipient if there is one.
Examples
use lettre::{message::Mailbox, Address};
let address = Address::new("example", "email.com")?;
let mailbox = Mailbox::new(None, address);Trait Implementations
Sourceimpl Ord for Mailbox
impl Ord for Mailbox
Sourceimpl PartialOrd for Mailbox
impl PartialOrd for Mailbox
impl Eq for Mailbox
impl StructuralPartialEq for Mailbox