pub struct Mailer { /* private fields */ }Expand description
Helps sending mails to users
Implementations
Sourceimpl Mailer
impl Mailer
Sourcepub fn new(
templates: Templates,
transport: MailTransport,
from: Mailbox,
reply_to: Mailbox,
) -> Self
pub fn new( templates: Templates, transport: MailTransport, from: Mailbox, reply_to: Mailbox, ) -> Self
Constructs a new Mailer
Sourcepub async fn send_verification_email(
&self,
to: Mailbox,
context: &WithLanguage<EmailVerificationContext>,
) -> Result<(), Error>
pub async fn send_verification_email( &self, to: Mailbox, context: &WithLanguage<EmailVerificationContext>, ) -> Result<(), Error>
Send the verification email to a user
Errors
Will return Err if the email failed rendering or failed sending
Sourcepub async fn send_recovery_email(
&self,
to: Mailbox,
context: &WithLanguage<EmailRecoveryContext>,
) -> Result<(), Error>
pub async fn send_recovery_email( &self, to: Mailbox, context: &WithLanguage<EmailRecoveryContext>, ) -> Result<(), Error>
Send the recovery email to a user
Errors
Will return Err if the email failed rendering or failed sending
Sourcepub async fn test_connection(&self) -> Result<(), Error>
pub async fn test_connection(&self) -> Result<(), Error>